const net = require('../../utils/net.js');
const util = require('../../utils/util.js');
const {
  api_house_detail,
  api_house_collect,
  api_house_cancel_collect,
  api_house_item_detail
} = require('../../utils/api.js');
Page({

  /**
   * 页面的初始数据
   */
  data: {
    id:null,
    isLoading:true,
    bannerData:null,
    schoolData:null,
    data:null,
    showHouseType:true,
    current:1,
    isCollect:0,
    markers: null,
    userInfo:null,

    hiddenMask:true,
    roomBannerData:null,
    roomCurrent:0,
    selectItem:null,

    showHomeBtn:false

  },

  /**
   * 生命周期函数--监听页面加载 43831
   */
  onLoad: function (options) {
    if (options && options.id) {
      let {id,mobile} = options;
      this.data.id = id;
      this.getHouseDetail();
      if(mobile && mobile.length) {
          util.setStorageSync('shareMobile',mobile);
      }
     
    }

    const pages = getCurrentPages(); 
    if(pages.length == 1) {
      this.setData({
        showHomeBtn:true
      })
    }

    this.getUserInfo();
   
  },
  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {
    const {share} = this.data.data;

    let path = '/pages/houseDetail/houseDetail?id='+ this.data.id;
    const userInfo =  util.getStorageSync('userInfo');
    if (userInfo && userInfo.mobile && userInfo.mobile.length) {
      path = path + '&mobile='+userInfo.mobile;
    }
    return {
      title:share.shareTitle,
      path:path,
      imageUrl:share.shareImgUrl,
      desc:share.shareContent
    }
  },

  loginCallback:function () {
    this.getUserInfo();
  },


  getUserInfo:function () {
    const userInfo = util.getStorageSync("userInfo");
    if (userInfo) {
      this.setData({
        userInfo:userInfo
      })
    }
  },

  getHouseDetail:function () {
    let params = {};
    params.url = api_house_detail;
    params.data={id:this.data.id};
    net.req(params, true).then((data) => {
      this.dealWithData(data);
    }, (e) => {
      this.setData({
        isLoading:false,
        data:null
      });

      util.showToast(e.msg,null,true);
      setTimeout(function(){
        　wx.navigateBack();　
      },800);
    });
    
  },

  dealWithData:function (data) {
    let {photos,school,marketTags} = data,tmp = new Array();
    for(var i = 0,n = marketTags.length; i < n; i ++) {
      var obj = marketTags[i];
      obj.bgColor = util.colorToRgba(obj.bgColor);
      obj.color = util.colorToRgba(obj.color);
      marketTags[i] = obj;
    }
    data.marketTags = marketTags;
    this.setData({
      isLoading:false,
      data:data,
      markers:[{
        iconPath: '../../imgs/marker.png',
        id: 0,
        latitude:data.lat,
        longitude:data.lng,
        width: 23,
        height: 30
      }]
    });

   
    if (photos) {
      if (photos.videos && photos.videos.length) {
        tmp = tmp.concat(photos.videos);
      }
      if (photos.images && photos.images.length) {
        tmp = tmp.concat(photos.images);
      }
      this.setData({
        bannerData:tmp,
        isCollect:data.collection
      });
    }

    if (school && school.length) {
      this.setData({
        schoolData:school[0]
      })
    }
  },

  tapBannerAction:function () {
    let {photos} = this.data.data;
    if (photos) {
      wx.navigateTo({
        url: '/pages/houseVideoImgs/houseVideoImgs?data=' + encodeURIComponent(JSON.stringify(this.data.data))
      });
    }
  },

  bindchange:function(e) {
    let {current} = e.detail;
    this.setData({
      current:current + 1
    })
  },

  tapHouseTypeAction:function() {
    this.setData({
      showHouseType:!this.data.showHouseType
    });
  },

  tapHouseDetailAction:function () {
    const data = this.data.data;
    let params = {
      countryText:data.countryText,
      attribute:data.attribute,
      address:data.address,
      code:data.code,
      introduce:data.introduce,
      surround:data.surround,
    }

    if (data.school && data.school.length) {
      params.school = data.school
    }

    wx.navigateTo({
      url: '/pages/houseIntro/houseIntro?data=' + encodeURIComponent(JSON.stringify(params)) 
    });
  },

  tapMoreFacilities:function () {
    const data = this.data.data.facilitiesTags;
    wx.navigateTo({
      url: '/pages/supportFacilities/supportFacilities?data=' + encodeURIComponent(JSON.stringify(data))
    });
  },

  lookAllHouseAction:function () {
    const data = this.data.data;
    let params = {
      name:data.name,
      rentTime:data.rentTime,
      moneyUnit:data.moneyUnit,
      price:data.price,
      rentTimeUnit:data.rentTimeUnit,
      rentNum:data.rentNum,
      applyText:data.applyText,
      id:data.id
    }
    if (data.photos && data.photos.images && data.photos.images.length) {
      params.imgObj = data.photos.images[0];
    }
    wx.navigateTo({
      url: '/pages/allHouse/allHouse?data=' + JSON.stringify(params)
    });
  },


  applyRoomAction:function (e) {
      let data = this.data.data,obj = e.detail.data;
      
      let params = {
        roomId:obj?obj.roomId : "",
        countryId:data.countryId,
        cityId:data.cityId,
        name:obj?obj.roomName:data.name,
        rentTime:obj?obj.rentTime:data.rentTime,
        moneyUnit:obj?obj.moneyUnit:data.moneyUnit,
        price:obj?obj.price:data.price,
        rentTimeUnit:obj?obj.rentTimeUnit:data.rentTimeUnit,
        rentNum:obj?obj.rentNum:data.rentNum,
        applyText:data.applyText,
        id:data.id
      }
      if (obj) {
        if (obj.attrId) {
          params.attrId = obj.attrId;
        }
      }
      
      if (data.photos && data.photos.images && data.photos.images.length) {
        params.imgObj = data.photos.images[0];
      }

      this.openApplyReserve(params);
      
  },


  openApplyReserve:function(data) {
    if (this.data.userInfo) {
      wx.navigateTo({
        url: '/pages/applyReserve/applyReserve?data=' + JSON.stringify(data)
      });
    } else {
      wx.navigateTo({
        url: '/pages/login/login'
      });
    }
  },

  collectAction:function () {
    if (this.data.userInfo) {
      const isCollect = this.data.isCollect;
      let params = {};
      params.url = isCollect == 1 ? api_house_cancel_collect : api_house_collect;
      params.data={
        cate:1,
        hid:this.data.id
      };
      net.req(params, true).then((data) => {
        this.setData({
          isCollect:!isCollect
        });
      }, (e) => {
      
      });
    } else {
      wx.navigateTo({
        url: '/pages/login/login'
      });
    }
  },

  tapMapAction:function () {
    const data = this.data.data;
    const params  = {
      lat:data.lat,
      lng:data.lng,
      markers:this.data.markers
    };
    wx.navigateTo({
      url: '/pages/map/map?data=' + JSON.stringify(params)
    });
  },

  showRentTimeAction:function (e) {
    const {currentIndex} = e.currentTarget.dataset;
    const data = this.data.data.items[currentIndex];
    data.isShow = !data.isShow;
    this.data.data.items[currentIndex] = data

    this.setData({
      data:this.data.data
    })
  },

  showRoomDetailAction:function (e) {
    const {currentIndex} = e.currentTarget.dataset;
    const data = this.data.data.items[currentIndex];
    const {roomId} = data;
    let params = {};
    params.url = api_house_item_detail;
    params.data={roomId:roomId};
    net.req(params, true).then((data) => {
      this.setData({
        detailData:data,
        hiddenMask:false,
        selectItem:currentIndex,
        roomCurrent:0
      });
      this.dealWithBannerData(data);
    }, (e) => {
      
    });
  },

  dealWithBannerData:function (data) {
    let {photos} = data,tmp = new Array();
    if (photos) {
      if (photos.images && photos.images.length) {
        tmp = tmp.concat(photos.images);
      }

      if (photos.videos && photos.videos.length) {
        tmp = tmp.concat(photos.videos);
      }

      this.setData({
        roomBannerData:tmp
      });
    }

  },

  bindRoomChange:function (e) {
    let {current} = e.detail;
    this.setData({
      roomCurrent:current
    })
  },

  closeAction:function () {
    this.setData({
      hiddenMask:true
    });
  },

  showRentTimeAction:function (e) {
    const {currentIndex} = e.currentTarget.dataset;
    const data = this.data.data.items[currentIndex];
    data.isShow = !data.isShow;
    this.data.data.items[currentIndex] = data

    this.setData({
      data: this.data.data,
      hiddenMask:true
    })
  },

  applyToastRoomAction:function () {
    let {data,detailData} = this.data;
    let params = {
      roomId:detailData.roomId,
      countryId:detailData.countryId,
      cityId:detailData.cityId,
      name:detailData.name,
      rentTime:detailData.rentTime,
      moneyUnit:detailData.moneyUnit,
      price:detailData.price,
      rentTimeUnit:detailData.rentTimeUnit,
      rentNum:detailData.rentNum,
      applyText:data.applyText,
      id:data.id
    }
    
    if (detailData.photos && detailData.photos.images && detailData.photos.images.length) {
      params.imgObj = detailData.photos.images[0];
    }

    this.openApplyReserve(params);
  },

  hiddenMaskAction:function () {
    this.setData({
      hiddenMask:true
    })
  },

  goHomeAction:function () {
    wx.reLaunch({
      url: '/pages/index/index'
    });
  },

  // 为了解决点击事件透传，最外层添加无用的点击方法
  tapAction:function() {

  }

})